Crate edgefirst_schemas

Crate edgefirst_schemas 

Modules

builtin_interfaces
ROS 2 RCL Interfaces
edgefirst_msgs
EdgeFirst Middleware Schemas
foxglove_msgs
Foxglove Messages
geometry_msgs
ROS 2 Common Interfaces
rosgraph_msgs
sensor_msgs
service
std_msgs

Structs

Point

Functions

decode_pcd
This function takes a PointCloud2 message and decodes it into a vector of Points. Each Point contains the x, y, z coordinates, an id, and a HashMap of additional fields.