Modules
- builtin_
interfaces - ROS 2 RCL Interfaces
- edgefirst_
msgs - EdgeFirst Middleware Schemas
- foxglove_
msgs - Foxglove Messages
- geometry_
msgs - ROS 2 Common Interfaces
- rosgraph_
msgs - sensor_
msgs - service
- std_
msgs
Structs
Functions
- decode_
pcd - This function takes a PointCloud2 message and decodes it into a vector of Points. Each Point contains the x, y, z coordinates, an id, and a HashMap of additional fields.